@@ -2,13 +2,14 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Index/DataWriter.h"
-#include "KinoSearch/Plan/Schema.h"
+#include "KinoSearch/Schema.h"
 #include "KinoSearch/Store/Folder.h"
 #include "KinoSearch/Index/PolyReader.h"
 #include "KinoSearch/Index/Segment.h"
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Index/Snapshot.h"
 #include "KinoSearch/Store/Folder.h"
+#include "KinoSearch/Util/I32Array.h"
 
 DataWriter*
 DataWriter_init(DataWriter *self, Schema *schema, Snapshot *snapshot,
@@ -45,13 +46,6 @@ DataWriter_get_schema(DataWriter *self) { return self->schema; }
 Folder*
 DataWriter_get_folder(DataWriter *self) { return self->folder; }
 
-void
-DataWriter_delete_segment(DataWriter *self, SegReader *reader)
-{
-    UNUSED_VAR(self);
-    UNUSED_VAR(reader);
-}
-
 void
 DataWriter_merge_segment(DataWriter *self, SegReader *reader, 
                          I32Array *doc_map)
@@ -69,7 +63,7 @@ DataWriter_metadata(DataWriter *self)
     return metadata;
 }
 
-/* Copyright 2007-2010 Marvin Humphrey
+/* Copyright 2007-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
