@@ -2,7 +2,7 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Index/TermStepper.h"
-#include "KinoSearch/Plan/Schema.h"
+#include "KinoSearch/Schema.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
 #include "KinoSearch/Util/StringHelper.h"
@@ -42,7 +42,14 @@ TermStepper_set_value(TermStepper *self, Obj *value)
     self->value = value ? INCREF(value) : NULL;
 }
 
-/* Copyright 2006-2010 Marvin Humphrey
+void
+TermStepper_mimic(TermStepper *self, Obj *other)
+{
+    TermStepper *evil_twin = (TermStepper*)ASSERT_IS_A(other, TERMSTEPPER);
+    Obj_Mimic(self, evil_twin->value);
+}
+
+/* Copyright 2006-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
