@@ -1,3 +1,6 @@
+#define C_KINO_CHARBUF
+#define C_KINO_VIEWCHARBUF
+#define C_KINO_ZOMBIECHARBUF
 #define KINO_USE_SHORT_NAMES
 #define CHY_USE_SHORT_NAMES
 
@@ -600,7 +603,7 @@ CB_trim_top(CharBuf *self)
     while (ptr < end) {
         u32_t code_point = StrHelp_decode_utf8_char(ptr);
         if (!StrHelp_is_whitespace(code_point)) break;
-        ptr += UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
         count++;
     }
 
@@ -636,7 +639,7 @@ CB_nip(CharBuf *self, size_t count)
     size_t       num_nipped = 0;
     char *const  end        = CBEND(self);
     char        *ptr        = self->ptr;
-    for ( ; ptr < end  && count--; ptr += UTF8_SKIP[*(u8_t*)ptr]) {
+    for ( ; ptr < end  && count--; ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]) {
         num_nipped++;
     }
     self->size = end - ptr;
@@ -652,8 +655,8 @@ CB_nip_one(CharBuf *self)
     }
     else {
         i32_t retval = (i32_t)StrHelp_decode_utf8_char(self->ptr);
-        size_t consumed = UTF8_SKIP[*(u8_t*)self->ptr];
-        char *ptr = self->ptr + UTF8_SKIP[*(u8_t*)self->ptr];
+        size_t consumed = StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
+        char *ptr = self->ptr + StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
         self->size -= consumed;
         memmove(self->ptr, ptr, self->size);
         return retval;
@@ -680,7 +683,7 @@ CB_length(CharBuf *self)
     char   *ptr  = self->ptr; 
     char   *end  = CBEND(self);
     while (ptr < end) {
-        ptr += UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
         len++;
     }
     return len;
@@ -703,7 +706,7 @@ CB_code_point_at(CharBuf *self, size_t tick)
     char *ptr = self->ptr;
     char *const end = CBEND(self);
 
-    for ( ; ptr < end; ptr += UTF8_SKIP[*(u8_t*)ptr]) {
+    for ( ; ptr < end; ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]) {
         if (count == tick) return StrHelp_decode_utf8_char(ptr);
         count++;
     }
@@ -831,7 +834,7 @@ ViewCB_trim_top(ViewCharBuf *self)
     while (ptr < end) {
         u32_t code_point = StrHelp_decode_utf8_char(ptr);
         if (!StrHelp_is_whitespace(code_point)) break;
-        ptr += UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
         count++;
     }
 
@@ -851,7 +854,7 @@ ViewCB_nip(ViewCharBuf *self, size_t count)
     char   *end    = CBEND(self);
     for (num_nipped = 0; 
          ptr < end && count--; 
-         ptr += UTF8_SKIP[*(u8_t*)ptr]
+         ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]
     ) {
         num_nipped++;
     }
@@ -868,7 +871,7 @@ ViewCB_nip_one(ViewCharBuf *self)
     }
     else {
         i32_t retval = (i32_t)StrHelp_decode_utf8_char(self->ptr);
-        size_t consumed = UTF8_SKIP[*(u8_t*)self->ptr];
+        size_t consumed = StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
         self->ptr  += consumed;
         self->size -= consumed;
         return retval;
