@@ -3,7 +3,7 @@
 
 #include "KinoSearch/Search/LeafQuery.h"
 #include "KinoSearch/Search/Compiler.h"
-#include "KinoSearch/Search/Searcher.h"
+#include "KinoSearch/Search/Searchable.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
 
@@ -41,7 +41,7 @@ LeafQuery_equals(LeafQuery *self, Obj *other)
 {
     LeafQuery *evil_twin = (LeafQuery*)other;
     if (evil_twin == self) return true;
-    if (!Obj_Is_A(other, LEAFQUERY)) return false;
+    if (!OBJ_IS_A(evil_twin, LEAFQUERY)) return false;
     if (self->boost != evil_twin->boost) return false;
     if (!!self->field ^ !!evil_twin->field) return false;
     if (self->field) {
@@ -89,16 +89,16 @@ LeafQuery_deserialize(LeafQuery *self, InStream *instream)
 }
 
 Compiler*
-LeafQuery_make_compiler(LeafQuery *self, Searcher *searcher, float boost) 
+LeafQuery_make_compiler(LeafQuery *self, Searchable *searchable, float boost) 
 {
     UNUSED_VAR(self);
-    UNUSED_VAR(searcher);
+    UNUSED_VAR(searchable);
     UNUSED_VAR(boost);
     THROW(ERR, "Can't Make_Compiler() from LeafQuery");
     UNREACHABLE_RETURN(Compiler*);
 }
 
-/* Copyright 2008-2010 Marvin Humphrey
+/* Copyright 2008-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
