@@ -2,12 +2,12 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Search/MatchAllQuery.h"
-#include "KinoSearch/Plan/Schema.h"
+#include "KinoSearch/Schema.h"
 #include "KinoSearch/Search/Span.h"
 #include "KinoSearch/Index/DocVector.h"
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Search/MatchAllScorer.h"
-#include "KinoSearch/Search/Searcher.h"
+#include "KinoSearch/Search/Searchable.h"
 #include "KinoSearch/Search/Similarity.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
@@ -30,7 +30,7 @@ bool_t
 MatchAllQuery_equals(MatchAllQuery *self, Obj *other)
 {
     MatchAllQuery *evil_twin = (MatchAllQuery*)other;
-    if (!Obj_Is_A(other, MATCHALLQUERY)) return false;
+    if (!OBJ_IS_A(evil_twin, MATCHALLQUERY)) return false;
     if (self->boost != evil_twin->boost) return false;
     return true;
 }
@@ -43,29 +43,29 @@ MatchAllQuery_to_string(MatchAllQuery *self)
 }
 
 Compiler*
-MatchAllQuery_make_compiler(MatchAllQuery *self, Searcher *searcher, 
+MatchAllQuery_make_compiler(MatchAllQuery *self, Searchable *searchable, 
                             float boost)
 {
-    return (Compiler*)MatchAllCompiler_new(self, searcher, boost);
+    return (Compiler*)MatchAllCompiler_new(self, searchable, boost);
 }
 
 /**********************************************************************/
 
 MatchAllCompiler*
-MatchAllCompiler_new(MatchAllQuery *parent, Searcher *searcher, 
+MatchAllCompiler_new(MatchAllQuery *parent, Searchable *searchable, 
                      float boost)
 {
     MatchAllCompiler *self 
         = (MatchAllCompiler*)VTable_Make_Obj(MATCHALLCOMPILER);
-    return MatchAllCompiler_init(self, parent, searcher, boost);
+    return MatchAllCompiler_init(self, parent, searchable, boost);
 }
 
 MatchAllCompiler*
 MatchAllCompiler_init(MatchAllCompiler *self, MatchAllQuery *parent, 
-                      Searcher *searcher, float boost)
+                      Searchable *searchable, float boost)
 {
     return (MatchAllCompiler*)Compiler_init((Compiler*)self, 
-        (Query*)parent, searcher, NULL, boost);
+        (Query*)parent, searchable, NULL, boost);
 }
 
 MatchAllCompiler*
@@ -86,7 +86,7 @@ MatchAllCompiler_make_matcher(MatchAllCompiler *self, SegReader *reader,
     return (Matcher*)MatchAllScorer_new(weight, SegReader_Doc_Max(reader));
 }
 
-/* Copyright 2006-2010 Marvin Humphrey
+/* Copyright 2006-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
