@@ -14,9 +14,9 @@ test_Dump_Load_and_Equals(TestBatch *batch)
     Obj          *dump  = (Obj*)NoMatchQuery_Dump(query);
     NoMatchQuery *clone = (NoMatchQuery*)NoMatchQuery_Load(query, dump);
 
-    TEST_TRUE(batch, NoMatchQuery_Equals(query, (Obj*)clone), 
+    ASSERT_TRUE(batch, NoMatchQuery_Equals(query, (Obj*)clone), 
         "Dump => Load round trip");
-    TEST_FALSE(batch, NoMatchQuery_Equals(query, (Obj*)&EMPTY), "Equals");
+    ASSERT_FALSE(batch, NoMatchQuery_Equals(query, (Obj*)&EMPTY), "Equals");
 
     DECREF(query);
     DECREF(dump);
@@ -27,13 +27,13 @@ test_Dump_Load_and_Equals(TestBatch *batch)
 void
 TestNoMatchQuery_run_tests()
 {
-    TestBatch *batch = TestBatch_new(2);
-    TestBatch_Plan(batch);
+    TestBatch *batch = Test_new_batch("TestNoMatchQuery", 2, NULL);
+    PLAN(batch);
     test_Dump_Load_and_Equals(batch);
-    DECREF(batch);
+    batch->destroy(batch);
 }
 
-/* Copyright 2005-2010 Marvin Humphrey
+/* Copyright 2005-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
