@@ -11,11 +11,11 @@
 #include "KinoSearch/Test/TestUtils.h"
 #include "KinoSearch/Analysis/Analyzer.h"
 #include "KinoSearch/Analysis/Tokenizer.h"
-#include "KinoSearch/Document/Doc.h"
-#include "KinoSearch/Index/Indexer.h"
+#include "KinoSearch/Doc.h"
+#include "KinoSearch/Indexer.h"
+#include "KinoSearch/QueryParser.h"
+#include "KinoSearch/Searcher.h"
 #include "KinoSearch/Search/Hits.h"
-#include "KinoSearch/Search/IndexSearcher.h"
-#include "KinoSearch/Search/QueryParser.h"
 #include "KinoSearch/Search/TermQuery.h"
 #include "KinoSearch/Search/PhraseQuery.h"
 #include "KinoSearch/Search/LeafQuery.h"
@@ -32,7 +32,7 @@
 #define make_poly_query   (Query*)kino_TestUtils_make_poly_query
 
 static TestQueryParser*
-logical_test_empty_phrase(uint32_t boolop)
+logical_test_empty_phrase(u32_t boolop)
 {
     Query   *tree = make_leaf_query(NULL, "\"\"");
     UNUSED_VAR(boolop);
@@ -40,14 +40,14 @@ logical_test_empty_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_empty_parens(uint32_t boolop)
+logical_test_empty_parens(u32_t boolop)
 {
     Query   *tree   = make_poly_query(boolop, NULL);
     return TestQP_new("()", tree, NULL, 0);
 }
 
 static TestQueryParser*
-logical_test_nested_empty_parens(uint32_t boolop)
+logical_test_nested_empty_parens(u32_t boolop)
 {
     Query   *inner   = make_poly_query(boolop, NULL);
     Query   *tree    = make_poly_query(boolop, inner, NULL);
@@ -55,7 +55,7 @@ logical_test_nested_empty_parens(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_nested_empty_phrase(uint32_t boolop)
+logical_test_nested_empty_phrase(u32_t boolop)
 {
     Query   *leaf   = make_leaf_query(NULL, "\"\"");
     Query   *tree   = make_poly_query(boolop, leaf, NULL);
@@ -63,7 +63,7 @@ logical_test_nested_empty_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_simple_term(uint32_t boolop)
+logical_test_simple_term(u32_t boolop)
 {
     Query   *tree   = make_leaf_query(NULL, "b");
     UNUSED_VAR(boolop);
@@ -71,7 +71,7 @@ logical_test_simple_term(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_one_nested_term(uint32_t boolop)
+logical_test_one_nested_term(u32_t boolop)
 {
     Query   *leaf   = make_leaf_query(NULL, "a");
     Query   *tree   = make_poly_query(boolop, leaf, NULL);
@@ -79,7 +79,7 @@ logical_test_one_nested_term(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_one_term_phrase(uint32_t boolop)
+logical_test_one_term_phrase(u32_t boolop)
 {
     Query   *tree   = make_leaf_query(NULL, "\"a\"");
     UNUSED_VAR(boolop);
@@ -87,59 +87,59 @@ logical_test_one_term_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_two_terms(uint32_t boolop)
+logical_test_two_terms(u32_t boolop)
 {
     Query   *a_leaf    = make_leaf_query(NULL, "a");
     Query   *b_leaf    = make_leaf_query(NULL, "b");
     Query   *tree      = make_poly_query(boolop, a_leaf, b_leaf, NULL); 
-    uint32_t num_hits  = boolop == BOOLOP_OR ? 4 : 3;
+    u32_t    num_hits  = boolop == BOOLOP_OR ? 4 : 3;
     return TestQP_new("a b", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_two_terms_nested(uint32_t boolop)
+logical_test_two_terms_nested(u32_t boolop)
 {
     Query   *a_leaf     = make_leaf_query(NULL, "a");
     Query   *b_leaf     = make_leaf_query(NULL, "b");
     Query   *tree       = make_poly_query(boolop, a_leaf, b_leaf, NULL); 
-    uint32_t num_hits   = boolop == BOOLOP_OR ? 4 : 3;
+    u32_t    num_hits   = boolop == BOOLOP_OR ? 4 : 3;
     return TestQP_new("(a b)", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_one_term_one_single_term_phrase(uint32_t boolop)
+logical_test_one_term_one_single_term_phrase(u32_t boolop)
 {
     Query   *a_leaf    = make_leaf_query(NULL, "a");
     Query   *b_leaf    = make_leaf_query(NULL, "\"b\"");
     Query   *tree      = make_poly_query(boolop, a_leaf, b_leaf, NULL); 
-    uint32_t num_hits  = boolop == BOOLOP_OR ? 4 : 3;
+    u32_t    num_hits  = boolop == BOOLOP_OR ? 4 : 3;
     return TestQP_new("a \"b\"", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_two_terms_one_nested(uint32_t boolop)
+logical_test_two_terms_one_nested(u32_t boolop)
 {
     Query   *a_leaf    = make_leaf_query(NULL, "a");
     Query   *b_leaf    = make_leaf_query(NULL, "b");
     Query   *b_tree    = make_poly_query(boolop, b_leaf, NULL);
     Query   *tree      = make_poly_query(boolop, a_leaf, b_tree, NULL);
-    uint32_t num_hits  = boolop == BOOLOP_OR ? 4 : 3;
+    u32_t    num_hits  = boolop == BOOLOP_OR ? 4 : 3;
     return TestQP_new("a (b)", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_one_term_one_nested_single_term_phrase(uint32_t boolop)
+logical_test_one_term_one_nested_single_term_phrase(u32_t boolop)
 {
     Query   *a_leaf    = make_leaf_query(NULL, "a");
     Query   *b_leaf    = make_leaf_query(NULL, "\"b\"");
     Query   *b_tree    = make_poly_query(boolop, b_leaf, NULL);
     Query   *tree      = make_poly_query(boolop, a_leaf, b_tree, NULL);
-    uint32_t num_hits  = boolop == BOOLOP_OR ? 4 : 3;
+    u32_t    num_hits  = boolop == BOOLOP_OR ? 4 : 3;
     return TestQP_new("a (\"b\")", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_phrase(uint32_t boolop)
+logical_test_phrase(u32_t boolop)
 {
     Query   *tree    = make_leaf_query(NULL, "\"a b\"");
     UNUSED_VAR(boolop);
@@ -147,7 +147,7 @@ logical_test_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_nested_phrase(uint32_t boolop)
+logical_test_nested_phrase(u32_t boolop)
 {
     Query   *leaf   = make_leaf_query(NULL, "\"a b\"");
     Query   *tree   = make_poly_query(boolop, leaf, NULL);
@@ -155,52 +155,52 @@ logical_test_nested_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_three_terms(uint32_t boolop)
+logical_test_three_terms(u32_t boolop)
 {
     Query   *a_leaf   = make_leaf_query(NULL, "a");
     Query   *b_leaf   = make_leaf_query(NULL, "b");
     Query   *c_leaf   = make_leaf_query(NULL, "c");
     Query   *tree     = make_poly_query(boolop, a_leaf, b_leaf, 
                                        c_leaf, NULL); 
-    uint32_t num_hits = boolop == BOOLOP_OR ? 4 : 2;
+    u32_t num_hits = boolop == BOOLOP_OR ? 4 : 2;
     return TestQP_new("a b c", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_three_terms_two_nested(uint32_t boolop)
+logical_test_three_terms_two_nested(u32_t boolop)
 {
     Query   *a_leaf     = make_leaf_query(NULL, "a");
     Query   *b_leaf     = make_leaf_query(NULL, "b");
     Query   *c_leaf     = make_leaf_query(NULL, "c");
     Query   *inner_tree = make_poly_query(boolop, b_leaf, c_leaf, NULL);
     Query   *tree       = make_poly_query(boolop, a_leaf, inner_tree, NULL);
-    uint32_t num_hits   = boolop == BOOLOP_OR ? 4 : 2;
+    u32_t    num_hits   = boolop == BOOLOP_OR ? 4 : 2;
     return TestQP_new("a (b c)", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_one_term_one_phrase(uint32_t boolop)
+logical_test_one_term_one_phrase(u32_t boolop)
 {
     Query   *a_leaf   = make_leaf_query(NULL, "a");
     Query   *bc_leaf  = make_leaf_query(NULL, "\"b c\"");
     Query   *tree     = make_poly_query(boolop, a_leaf, bc_leaf, NULL);
-    uint32_t num_hits = boolop == BOOLOP_OR ? 4 : 2;
+    u32_t    num_hits = boolop == BOOLOP_OR ? 4 : 2;
     return TestQP_new("a \"b c\"", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_one_term_one_nested_phrase(uint32_t boolop)
+logical_test_one_term_one_nested_phrase(u32_t boolop)
 {
     Query   *a_leaf     = make_leaf_query(NULL, "a");
     Query   *bc_leaf    = make_leaf_query(NULL, "\"b c\"");
     Query   *inner_tree = make_poly_query(boolop, bc_leaf, NULL);
     Query   *tree       = make_poly_query(boolop, a_leaf, inner_tree, NULL);
-    uint32_t num_hits   = boolop == BOOLOP_OR ? 4 : 2;
+    u32_t    num_hits   = boolop == BOOLOP_OR ? 4 : 2;
     return TestQP_new("a (\"b c\")", tree, NULL, num_hits);
 }
 
 static TestQueryParser*
-logical_test_long_phrase(uint32_t boolop)
+logical_test_long_phrase(u32_t boolop)
 {
     Query   *tree   = make_leaf_query(NULL, "\"a b c\"");
     UNUSED_VAR(boolop);
@@ -208,7 +208,7 @@ logical_test_long_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_pure_negation(uint32_t boolop)
+logical_test_pure_negation(u32_t boolop)
 {
     Query   *leaf   = make_leaf_query(NULL, "x");
     Query   *tree   = make_not_query(leaf);
@@ -217,7 +217,7 @@ logical_test_pure_negation(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_double_negative(uint32_t boolop)
+logical_test_double_negative(u32_t boolop)
 {
     Query   *tree   = make_leaf_query(NULL, "a");
     UNUSED_VAR(boolop);
@@ -225,7 +225,7 @@ logical_test_double_negative(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_triple_negative(uint32_t boolop)
+logical_test_triple_negative(u32_t boolop)
 {
     Query   *leaf   = make_leaf_query(NULL, "a");
     Query   *tree   = make_not_query(leaf);
@@ -233,11 +233,12 @@ logical_test_triple_negative(uint32_t boolop)
     return TestQP_new("---a", tree, NULL, 0);
 }
 
-// Technically, this should produce an acceptably small result set, but it's
-// too difficult to prune -- so QParser_Prune just lops it because it's a
-// top-level NOTQuery.
+/* Technically, this should produce an acceptably small result set, but it's
+ * too difficult to prune -- so QParser_Prune just lops it because it's a
+ * top-level NOTQuery.
+ */
 static TestQueryParser*
-logical_test_nested_negations(uint32_t boolop)
+logical_test_nested_negations(u32_t boolop)
 {
     Query *query = make_leaf_query(NULL, "a");
     query = make_poly_query(boolop, query, NULL);
@@ -248,7 +249,7 @@ logical_test_nested_negations(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_two_terms_one_required(uint32_t boolop)
+logical_test_two_terms_one_required(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -265,7 +266,7 @@ logical_test_two_terms_one_required(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_intersection(uint32_t boolop)
+logical_test_intersection(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -275,7 +276,7 @@ logical_test_intersection(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_three_way_intersection(uint32_t boolop)
+logical_test_three_way_intersection(u32_t boolop)
 {
     Query *a_query = make_leaf_query(NULL, "a");
     Query *b_query = make_leaf_query(NULL, "b");
@@ -287,7 +288,7 @@ logical_test_three_way_intersection(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_union(uint32_t boolop)
+logical_test_union(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -297,7 +298,7 @@ logical_test_union(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_three_way_union(uint32_t boolop)
+logical_test_three_way_union(u32_t boolop)
 {
     Query *a_query = make_leaf_query(NULL, "a");
     Query *b_query = make_leaf_query(NULL, "b");
@@ -308,7 +309,7 @@ logical_test_three_way_union(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_a_or_plus_b(uint32_t boolop)
+logical_test_a_or_plus_b(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -318,7 +319,7 @@ logical_test_a_or_plus_b(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_and_not(uint32_t boolop)
+logical_test_and_not(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -329,7 +330,7 @@ logical_test_and_not(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_nested_or(uint32_t boolop)
+logical_test_nested_or(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -340,7 +341,7 @@ logical_test_nested_or(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_and_nested_or(uint32_t boolop)
+logical_test_and_nested_or(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -352,7 +353,7 @@ logical_test_and_nested_or(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_or_nested_or(uint32_t boolop)
+logical_test_or_nested_or(u32_t boolop)
 {
     Query   *a_query = make_leaf_query(NULL, "a");
     Query   *b_query = make_leaf_query(NULL, "b");
@@ -364,7 +365,7 @@ logical_test_or_nested_or(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_and_not_nested_or(uint32_t boolop)
+logical_test_and_not_nested_or(u32_t boolop)
 {
     Query *a_query    = make_leaf_query(NULL, "a");
     Query *b_query    = make_leaf_query(NULL, "b");
@@ -378,7 +379,7 @@ logical_test_and_not_nested_or(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_required_phrase_negated_term(uint32_t boolop)
+logical_test_required_phrase_negated_term(u32_t boolop)
 {
     Query *bc_query   = make_leaf_query(NULL, "\"b c\"");
     Query *d_query    = make_leaf_query(NULL, "d");
@@ -389,7 +390,7 @@ logical_test_required_phrase_negated_term(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_required_term_optional_phrase(uint32_t boolop)
+logical_test_required_term_optional_phrase(u32_t boolop)
 {
     Query *ab_query   = make_leaf_query(NULL, "\"a b\"");
     Query *d_query    = make_leaf_query(NULL, "d");
@@ -407,7 +408,7 @@ logical_test_required_term_optional_phrase(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_nested_nest(uint32_t boolop)
+logical_test_nested_nest(u32_t boolop)
 {
     Query *a_query    = make_leaf_query(NULL, "a");
     Query *b_query    = make_leaf_query(NULL, "b");
@@ -422,7 +423,7 @@ logical_test_nested_nest(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_field_bool_group(uint32_t boolop)
+logical_test_field_bool_group(u32_t boolop)
 {
     Query   *b_query = make_leaf_query("content", "b");
     Query   *c_query = make_leaf_query("content", "c");
@@ -432,7 +433,7 @@ logical_test_field_bool_group(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_field_multi_OR(uint32_t boolop)
+logical_test_field_multi_OR(u32_t boolop)
 {
     Query *a_query = make_leaf_query("content", "a");
     Query *b_query = make_leaf_query("content", "b");
@@ -443,7 +444,7 @@ logical_test_field_multi_OR(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_field_multi_AND(uint32_t boolop)
+logical_test_field_multi_AND(u32_t boolop)
 {
     Query *a_query = make_leaf_query("content", "a");
     Query *b_query = make_leaf_query("content", "b");
@@ -455,7 +456,7 @@ logical_test_field_multi_AND(uint32_t boolop)
 }
 
 static TestQueryParser*
-logical_test_field_phrase(uint32_t boolop)
+logical_test_field_phrase(u32_t boolop)
 {
     Query   *tree = make_leaf_query("content", "\"b c\"");
     UNUSED_VAR(boolop);
@@ -543,7 +544,7 @@ prune_test_not_and_not()
 /***************************************************************************/
 
 typedef TestQueryParser*
-(*kino_TestQPLogic_logical_test_t)(uint32_t boolop_sym);
+(*kino_TestQPLogic_logical_test_t)(u32_t boolop_sym);
 
 static kino_TestQPLogic_logical_test_t logical_test_funcs[] = {
     logical_test_empty_phrase,
@@ -611,12 +612,12 @@ S_create_index()
     RAMFolder  *folder  = RAMFolder_new(NULL);
     VArray     *doc_set = TestUtils_doc_set();
     Indexer    *indexer = Indexer_new(schema, (Obj*)folder, NULL, 0);
-    uint32_t i, max;
+    u32_t i, max;
 
-    CharBuf *field = (CharBuf*)ZCB_WRAP_STR("content", 7);
     for (i = 0, max = VA_Get_Size(doc_set); i < max; i++) {
+        static ZombieCharBuf field = ZCB_LITERAL("content");
         Doc *doc = Doc_new(NULL, 0);
-        Doc_Store(doc, field, VA_Fetch(doc_set, i));
+        Doc_Store(doc, (CharBuf*)&field, VA_Fetch(doc_set, i));
         Indexer_Add_Doc(indexer, doc, 1.0f);
         DECREF(doc);
     }
@@ -633,31 +634,31 @@ S_create_index()
 void
 TestQPLogic_run_tests()
 {
-    uint32_t i;
-    TestBatch     *batch      = TestBatch_new(178);
-    Folder        *folder     = S_create_index();
-    IndexSearcher *searcher   = IxSearcher_new((Obj*)folder);
-    QueryParser   *or_parser  = QParser_new(IxSearcher_Get_Schema(searcher), 
+    u32_t i;
+    TestBatch   *batch = Test_new_batch("TestQueryParserLogic", 178, NULL);
+    Folder      *folder       = S_create_index();
+    Searcher    *searcher     = Searcher_new((Obj*)folder);
+    QueryParser *or_parser    = QParser_new(Searcher_Get_Schema(searcher), 
         NULL, NULL, NULL);
-    ZombieCharBuf *AND        = ZCB_WRAP_STR("AND", 3);
-    QueryParser   *and_parser = QParser_new(IxSearcher_Get_Schema(searcher), 
-        NULL, (CharBuf*)AND, NULL);
+    static  ZombieCharBuf AND = ZCB_LITERAL("AND");
+    QueryParser *and_parser   = QParser_new(Searcher_Get_Schema(searcher), 
+        NULL, (CharBuf*)&AND, NULL);
     QParser_Set_Heed_Colons(or_parser, true);
     QParser_Set_Heed_Colons(and_parser, true);
 
-    TestBatch_Plan(batch);
+    PLAN(batch);
 
-    // Run logical tests with default boolop of OR. 
+    /* Run logical tests with default boolop of OR. */
     for (i = 0; logical_test_funcs[i] != NULL; i++) {
         kino_TestQPLogic_logical_test_t test_func = logical_test_funcs[i];
         TestQueryParser *test_case = test_func(BOOLOP_OR);
         Query *tree     = QParser_Tree(or_parser, test_case->query_string);
         Query *parsed   = QParser_Parse(or_parser, test_case->query_string);
-        Hits  *hits     = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits     = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
-        TEST_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
+        ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree() OR   %s", (char*)CB_Get_Ptr8(test_case->query_string));
-        TEST_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
+        ASSERT_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
             "hits: OR   %s", (char*)CB_Get_Ptr8(test_case->query_string));
         DECREF(hits);
         DECREF(parsed);
@@ -665,17 +666,17 @@ TestQPLogic_run_tests()
         DECREF(test_case);
     }
 
-    // Run logical tests with default boolop of AND. 
+    /* Run logical tests with default boolop of AND. */
     for (i = 0; logical_test_funcs[i] != NULL; i++) {
         kino_TestQPLogic_logical_test_t test_func = logical_test_funcs[i];
         TestQueryParser *test_case = test_func(BOOLOP_AND);
         Query *tree     = QParser_Tree(and_parser, test_case->query_string);
         Query *parsed   = QParser_Parse(and_parser, test_case->query_string);
-        Hits  *hits     = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits     = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
-        TEST_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
+        ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree() AND   %s", (char*)CB_Get_Ptr8(test_case->query_string));
-        TEST_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
+        ASSERT_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
             "hits: AND   %s", (char*)CB_Get_Ptr8(test_case->query_string));
         DECREF(hits);
         DECREF(parsed);
@@ -683,12 +684,12 @@ TestQPLogic_run_tests()
         DECREF(test_case);
     }
 
-    // Run tests for QParser_Prune(). 
+    /* Run tests for QParser_Prune(). */
     for (i = 0; prune_test_funcs[i] != NULL; i++) {
         kino_TestQPLogic_prune_test_t test_func = prune_test_funcs[i];
         TestQueryParser *test_case = test_func();
         CharBuf *qstring = test_case->tree 
-                         ? Query_To_String(test_case->tree)
+                         ? Obj_To_String(test_case->tree)
                          : CB_new_from_trusted_utf8("(NULL)", 6);
         Query *tree = test_case->tree;
         Query *wanted = test_case->expanded;
@@ -696,11 +697,11 @@ TestQPLogic_run_tests()
         Query *expanded;
         Hits  *hits;
 
-        TEST_TRUE(batch, Query_Equals(pruned, (Obj*)wanted),
+        ASSERT_TRUE(batch, Query_Equals(pruned, (Obj*)wanted),
             "prune()   %s", (char*)CB_Get_Ptr8(qstring));
         expanded = QParser_Expand(or_parser, pruned);
-        hits = IxSearcher_Hits(searcher, (Obj*)expanded, 0, 10, NULL);
-        TEST_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
+        hits = Searcher_Hits(searcher, (Obj*)expanded, 0, 10, NULL);
+        ASSERT_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
             "hits:    %s", (char*)CB_Get_Ptr8(qstring));
 
         DECREF(hits);
@@ -714,9 +715,9 @@ TestQPLogic_run_tests()
     DECREF(or_parser);
     DECREF(searcher);
     DECREF(folder);
-    DECREF(batch);
+    batch->destroy(batch);
 }
-/* Copyright 2005-2010 Marvin Humphrey
+/* Copyright 2005-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
