@@ -4,18 +4,18 @@ use warnings;
 package KinoSearch;
 
 use 5.008003;
-use Exporter;
 
-our $VERSION = '0.30_13';
+our $VERSION = '0.30_071';
 $VERSION = eval $VERSION;
 
 use XSLoader;
 # This loads a large number of disparate subs.
-BEGIN { XSLoader::load( 'KinoSearch', '0.30_13' ) }
+# See the docs for KinoSearch::Util::ToolSet.
+BEGIN { XSLoader::load( 'KinoSearch', '0.30_071' ) }
 
 BEGIN {
     push our @ISA, 'Exporter';
-    our @EXPORT_OK = qw( to_kino to_perl kdump );
+    our @EXPORT_OK = qw( kdump );
 }
 
 use KinoSearch::Autobinding;
@@ -28,8 +28,6 @@ sub kdump {
     warn $kdumper->Dump;
 }
 
-sub error {$KinoSearch::Object::Err::error}
-
 {
     package KinoSearch::Util::IndexFileNames;
     BEGIN {
@@ -58,47 +56,25 @@ sub error {$KinoSearch::Object::Err::error}
 }
 
 {
-    # Temporary back compat.
-    package KinoSearch::Doc;
-    BEGIN { our @ISA = qw( KinoSearch::Document::Doc ) }
-    package KinoSearch::Architecture;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Architecture ) }
-    package KinoSearch::FieldType;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::FieldType ) }
-    package KinoSearch::FieldType::BlobType;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::BlobType ) }
-    package KinoSearch::FieldType::Float32Type;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Float32Type ) }
-    package KinoSearch::FieldType::Float64Type;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Float64Type ) }
-    package KinoSearch::FieldType::Int32Type;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Int32Type ) }
-    package KinoSearch::FieldType::Int64Type;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Int64Type ) }
-    package KinoSearch::FieldType::FullTextType;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::FullTextType ) }
-    package KinoSearch::FieldType::StringType;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::StringType ) }
-    package KinoSearch::Indexer;
-    BEGIN { our @ISA = qw( KinoSearch::Index::Indexer ) }
-    package KinoSearch::Obj::BitVector;
-    BEGIN { our @ISA = qw( KinoSearch::Object::BitVector ) }
-    package KinoSearch::QueryParser;
-    BEGIN { our @ISA = qw( KinoSearch::Search::QueryParser ) }
-    package KinoSearch::Search::HitCollector;
-    BEGIN { our @ISA = qw( KinoSearch::Search::Collector ) }
-    package KinoSearch::Search::HitCollector::BitCollector;
-    BEGIN { our @ISA = qw( KinoSearch::Search::Collector::BitCollector ) }
-    package KinoSearch::Search::Searchable;
-    BEGIN { our @ISA = qw( KinoSearch::Search::Searcher ) }
-    package KinoSearch::Search::Similarity;
-    BEGIN { our @ISA = qw( KinoSearch::Index::Similarity ) }
-    package KinoSearch::Schema;
-    BEGIN { our @ISA = qw( KinoSearch::Plan::Schema ) }
-    package KinoSearch::Searcher;
-    BEGIN { our @ISA = qw( KinoSearch::Search::IndexSearcher ) }
-    package KinoSearch::Util::BitVector;
-    BEGIN { our @ISA = qw( KinoSearch::Object::BitVector ) }
+    package KinoSearch::Util::ToolSet;
+    use Carp qw( carp croak cluck confess );
+    use Scalar::Util qw( blessed );
+    use Storable qw( nfreeze thaw );
+
+    BEGIN {
+        push our @ISA, 'Exporter';
+        our @EXPORT_OK = qw(
+            carp
+            croak
+            cluck
+            confess
+            blessed
+            nfreeze
+            thaw
+            to_kino
+            to_perl
+        );
+    }
 }
 
 {
@@ -120,7 +96,7 @@ sub error {$KinoSearch::Object::Err::error}
 
 {
     package KinoSearch::Analysis::Stopalizer;
-    use KinoSearch qw( to_kino );
+    use KinoSearch::Util::ToolSet qw( to_kino );
 
     sub gen_stoplist {
         my ( undef, $language ) = @_;
@@ -161,8 +137,8 @@ sub error {$KinoSearch::Object::Err::error}
 }
 
 {
-    package KinoSearch::Document::Doc;
-    use Storable qw( nfreeze thaw );
+    package KinoSearch::Doc;
+    use KinoSearch::Util::ToolSet qw( nfreeze thaw );
     use bytes;
     no bytes;
 
@@ -174,42 +150,32 @@ sub error {$KinoSearch::Object::Err::error}
         my ( $self, $outstream ) = @_;
         my $buf = nfreeze( $self->get_fields );
         $outstream->write_c32( bytes::length($buf) );
-        $outstream->print($buf);
+        $outstream->write_bytes($buf);
     }
 
     sub deserialize_fields {
         my ( $self, $instream ) = @_;
         my $len = $instream->read_c32;
         my $buf;
-        $instream->read( $buf, $len );
+        $instream->read_bytes( $buf, $len );
         $self->set_fields( thaw($buf) );
     }
 }
 
 {
-    package KinoSearch::Object::I32Array;
-    our %new_PARAMS = ( ints => undef );
-}
-
-{
-    package KinoSearch::Object::LockFreeRegistry;
-    sub DESTROY { }    # leak all
-}
-
-{
-    package KinoSearch::Object::Obj;
-    use KinoSearch qw( to_kino to_perl );
+    package KinoSearch::Obj;
+    use KinoSearch::Util::ToolSet qw( to_kino to_perl );
     sub load { return $_[0]->_load( to_kino( $_[1] ) ) }
 }
 
 {
-    package KinoSearch::Object::VTable;
+    package KinoSearch::Obj::VTable;
 
     sub find_parent_class {
         my ( undef, $package ) = @_;
         no strict 'refs';
         for my $parent ( @{"$package\::ISA"} ) {
-            return $parent if $parent->isa('KinoSearch::Object::Obj');
+            return $parent if $parent->isa('KinoSearch::Obj');
         }
         return;
     }
@@ -217,13 +183,13 @@ sub error {$KinoSearch::Object::Err::error}
     sub novel_host_methods {
         my ( undef, $package ) = @_;
         no strict 'refs';
-        my $stash   = \%{"$package\::"};
-        my $methods = KinoSearch::Object::VArray->new(
-            capacity => scalar keys %$stash );
+        my $stash = \%{"$package\::"};
+        my $methods
+            = KinoSearch::Obj::VArray->new( capacity => scalar keys %$stash );
         while ( my ( $symbol, $glob ) = each %$stash ) {
             next if ref $glob;
             next unless *$glob{CODE};
-            $methods->push( KinoSearch::Object::CharBuf->new($symbol) );
+            $methods->push( KinoSearch::Obj::CharBuf->new($symbol) );
         }
         return $methods;
     }
@@ -239,23 +205,8 @@ sub error {$KinoSearch::Object::Err::error}
     }
 }
 
-{
-    package KinoSearch::Index::Indexer;
-
-    sub new {
-        my ( $either, %args ) = @_;
-        my $flags = 0;
-        $flags |= CREATE   if delete $args{'create'};
-        $flags |= TRUNCATE if delete $args{'truncate'};
-        return $either->_new( %args, flags => $flags );
-    }
-
-    our %add_doc_PARAMS = ( doc => undef, boost => 1.0 );
-}
-
 {
     package KinoSearch::Index::IndexReader;
-    use Carp;
 
     sub new {
         confess(
@@ -268,10 +219,9 @@ sub error {$KinoSearch::Object::Err::error}
         return;
     }
     sub posting_list {
-        my $self = shift;
-        my $plist_reader
-            = $self->fetch("KinoSearch::Index::PostingListReader");
-        return $plist_reader->posting_list(@_) if $plist_reader;
+        my $self        = shift;
+        my $post_reader = $self->fetch("KinoSearch::Index::PostingsReader");
+        return $post_reader->posting_list(@_) if $post_reader;
         return;
     }
     sub offsets { shift->_offsets->to_arrayref }
@@ -279,23 +229,26 @@ sub error {$KinoSearch::Object::Err::error}
 
 {
     package KinoSearch::Index::PolyReader;
-    use KinoSearch qw( to_kino );
+    use KinoSearch::Util::ToolSet qw( to_kino );
 
     sub try_read_snapshot {
         my ( undef, %args ) = @_;
-        my ( $snapshot, $folder, $path ) = @args{qw( snapshot folder path )};
-        eval { $snapshot->read_file( folder => $folder, path => $path ); };
-        if   ($@) { return KinoSearch::Object::CharBuf->new($@) }
+        my ( $snapshot, $folder, $filename )
+            = @args{qw( snapshot folder filename )};
+        eval {
+            $snapshot->read_file( folder => $folder, filename => $filename );
+        };
+        if   ($@) { return KinoSearch::Obj::CharBuf->new($@) }
         else      { return undef }
     }
 
     sub try_open_segreaders {
         my ( $self, $segments ) = @_;
-        my $schema      = $self->get_schema;
-        my $folder      = $self->get_folder;
-        my $snapshot    = $self->get_snapshot;
-        my $seg_readers = KinoSearch::Object::VArray->new(
-            capacity => scalar @$segments );
+        my $schema   = $self->get_schema;
+        my $folder   = $self->get_folder;
+        my $snapshot = $self->get_snapshot;
+        my $seg_readers
+            = KinoSearch::Obj::VArray->new( capacity => scalar @$segments );
         my $segs = to_kino($segments);    # FIXME: Don't convert twice.
         eval {
             # Create a SegReader for each segment in the index.
@@ -312,7 +265,7 @@ sub error {$KinoSearch::Object::Err::error}
             }
         };
         if ($@) {
-            return KinoSearch::Object::CharBuf->new($@);
+            return KinoSearch::Obj::CharBuf->new($@);
         }
         return $seg_readers;
     }
@@ -320,7 +273,7 @@ sub error {$KinoSearch::Object::Err::error}
 
 {
     package KinoSearch::Index::Segment;
-    use KinoSearch qw( to_kino );
+    use KinoSearch::Util::ToolSet qw( to_kino );
     sub store_metadata {
         my ( $self, %args ) = @_;
         $self->_store_metadata( %args,
@@ -335,7 +288,7 @@ sub error {$KinoSearch::Object::Err::error}
         my $self = shift;
         my $arch = $self->get_schema->get_architecture;
         eval { $arch->init_seg_reader($self); };
-        if ($@) { return KinoSearch::Object::CharBuf->new($@); }
+        if ($@) { return KinoSearch::Obj::CharBuf->new($@); }
         return;
     }
 }
@@ -345,10 +298,23 @@ sub error {$KinoSearch::Object::Err::error}
     our %value_PARAMS = ( ord => undef, );
 }
 
+{
+    package KinoSearch::Indexer;
+
+    sub new {
+        my ( $either, %args ) = @_;
+        my $flags = 0;
+        $flags |= CREATE   if delete $args{'create'};
+        $flags |= TRUNCATE if delete $args{'truncate'};
+        return $either->_new( %args, flags => $flags );
+    }
+
+    our %add_doc_PARAMS = ( doc => undef, boost => 1.0 );
+}
+
 {
     package KinoSearch::Search::Compiler;
-    use Carp;
-    use Scalar::Util qw( blessed );
+    use KinoSearch::Util::ToolSet qw( confess blessed );
 
     sub new {
         my ( $either, %args ) = @_;
@@ -390,27 +356,39 @@ sub error {$KinoSearch::Object::Err::error}
 }
 
 {
-    package KinoSearch::Object::BitVector;
+    package KinoSearch::Obj::BitVector;
     sub to_arrayref { shift->to_array->to_arrayref }
+
+    # Temporary back compat.
+    package KinoSearch::Util::BitVector;
+    BEGIN { push our @ISA, 'KinoSearch::Obj::BitVector' }
 }
 
 {
-    package KinoSearch::Object::ByteBuf;
+    package KinoSearch::Obj::ByteBuf;
+    BEGIN {
+        push our @ISA, 'Exporter';
+        our @EXPORT_OK = qw( bb_compare );    # testing only
+    }
+
     {
         # Override autogenerated deserialize binding.
         no warnings 'redefine';
         sub deserialize { shift->_deserialize(@_) }
     }
-}
 
-{
-    package KinoSearch::Object::ViewByteBuf;
-    use Carp;
+    package KinoSearch::Obj::ViewByteBuf;
+    use KinoSearch::Util::ToolSet qw( confess );
+
     sub new { confess "ViewByteBuf objects can only be created from C." }
 }
 
 {
-    package KinoSearch::Object::CharBuf;
+    package KinoSearch::Obj::CharBuf;
+    BEGIN {
+        push our @ISA, 'Exporter';
+        our @EXPORT_OK = qw( cb_compare );
+    }
 
     {
         # Defeat obscure bugs in the XS auto-generation by redefining clone()
@@ -421,125 +399,54 @@ sub error {$KinoSearch::Object::Err::error}
         sub clone       { shift->_clone(@_) }
         sub deserialize { shift->_deserialize(@_) }
     }
-}
 
-{
-    package KinoSearch::Object::ViewCharBuf;
-    use Carp;
+    package KinoSearch::Obj::ViewCharBuf;
+    use KinoSearch::Util::ToolSet qw( confess );
+
     sub new { confess "ViewCharBuf has no public constructor." }
-}
 
-{
-    package KinoSearch::Object::ZombieCharBuf;
-    use Carp;
+    package KinoSearch::Obj::ZombieCharBuf;
+    use KinoSearch::Util::ToolSet qw( confess );
+
     sub new { confess "ZombieCharBuf objects can only be created from C." }
+
     sub DESTROY { }
 }
 
 {
-    package KinoSearch::Object::Err;
+    package KinoSearch::Obj::Err;
     sub do_to_string { shift->to_string }
-    use Scalar::Util qw( blessed );
-    use Carp qw( confess longmess );
+    use Carp qw( longmess );
     use overload
         '""'     => \&do_to_string,
         fallback => 1;
 
-    sub new {
-        my ( $either, $message ) = @_;
-        my ( undef, $file, $line ) = caller;
-        $message .= ", $file line $line\n";
-        return $either->_new(
-            mess => KinoSearch::Object::CharBuf->new($message) );
-    }
-
     sub do_throw {
         my $err = shift;
         $err->cat_mess( longmess() );
         die $err;
     }
-
-    our $error;
-    sub set_error {
-        my $val = $_[1];
-        if ( defined $val ) {
-            confess("Not a KinoSearch::Object::Err")
-                unless ( blessed($val)
-                && $val->isa("KinoSearch::Object::Err") );
-        }
-        $error = $val;
-    }
-    sub get_error {$error}
 }
 
 {
-    package KinoSearch::Object::Hash;
+    package KinoSearch::Obj::Hash;
     no warnings 'redefine';
     sub deserialize { shift->_deserialize(@_) }
 }
 
 {
-    package KinoSearch::Object::VArray;
+    package KinoSearch::Obj::VArray;
     no warnings 'redefine';
     sub clone       { CORE::shift->_clone }
     sub deserialize { CORE::shift->_deserialize(@_) }
 }
 
 {
-    package KinoSearch::Store::FileHandle;
-    BEGIN {
-        push our @ISA, 'Exporter';
-        our @EXPORT_OK = qw( build_fh_flags );
-    }
-
-    sub build_fh_flags {
-        my $args  = shift;
-        my $flags = 0;
-        $flags |= FH_CREATE     if delete $args->{create};
-        $flags |= FH_READ_ONLY  if delete $args->{read_only};
-        $flags |= FH_WRITE_ONLY if delete $args->{write_only};
-        $flags |= FH_EXCLUSIVE  if delete $args->{exclusive};
-        return $flags;
-    }
-
-    sub open {
-        my ( $either, %args ) = @_;
-        $args{flags} ||= 0;
-        $args{flags} |= build_fh_flags( \%args );
-        return $either->_open(%args);
-    }
-}
-
-{
-    package KinoSearch::Store::FSFileHandle;
-
-    sub open {
-        my ( $either, %args ) = @_;
-        $args{flags} ||= 0;
-        $args{flags}
-            |= KinoSearch::Store::FileHandle::build_fh_flags( \%args );
-        return $either->_open(%args);
-    }
-}
-
-{
-    package KinoSearch::Store::FSFolder;
+    package KinoSearch::Util::Compat::DirManip;
     use File::Spec::Functions qw( rel2abs );
     sub absolutify { return rel2abs( $_[1] ) }
 }
 
-{
-    package KinoSearch::Store::RAMFileHandle;
-
-    sub open {
-        my ( $either, %args ) = @_;
-        $args{flags} ||= 0;
-        $args{flags}
-            |= KinoSearch::Store::FileHandle::build_fh_flags( \%args );
-        return $either->_open(%args);
-    }
-}
-
 {
     package KinoSearch::Util::Debug;
     BEGIN {
@@ -557,10 +464,14 @@ sub error {$KinoSearch::Object::Err::error}
     }
 }
 
+{
+    package KinoSearch::Util::I32Array;
+    our %new_PARAMS = ( ints => undef );
+}
+
 {
     package KinoSearch::Util::Json;
-    use Scalar::Util qw( blessed );
-    use KinoSearch qw( to_kino );
+    use KinoSearch::Util::ToolSet qw( to_kino );
 
     use JSON::XS qw();
 
@@ -568,46 +479,23 @@ sub error {$KinoSearch::Object::Err::error}
 
     sub slurp_json {
         my ( undef, %args ) = @_;
-        my $instream = $args{folder}->open_in( $args{path} )
-            or return;
+        my $instream = $args{folder}->open_in( $args{filename} );
+        return unless $instream;
         my $len = $instream->length;
         my $json;
-        $instream->read( $json, $len );
+        $instream->read_bytes( $json, $len );
         my $result = eval { to_kino( $json_encoder->decode($json) ) };
-        if ( $@ or !$result ) {
-            KinoSearch::Object::Err->set_error(
-                KinoSearch::Object::Err->new( $@ || "Failed to decode JSON" )
-            );
-            return;
-        }
+        return if $@;
         return $result;
     }
 
     sub spew_json {
         my ( undef, %args ) = @_;
-        my $json = eval { $json_encoder->encode( $args{'dump'} ) };
-        if ( !defined $json ) {
-            KinoSearch::Object::Err->set_error(
-                KinoSearch::Object::Err->new($@) );
-            return 0;
-        }
-        my $outstream = $args{folder}->open_out( $args{path} );
+        my $json      = $json_encoder->encode( $args{'dump'} );
+        my $outstream = $args{folder}->open_out( $args{filename} );
         return 0 unless $outstream;
-        eval {
-            $outstream->print($json);
-            $outstream->close;
-        };
-        if ($@) {
-            my $error;
-            if ( blessed($@) && $@->isa("KinoSearch::Object::Err") ) {
-                $error = $@;
-            }
-            else {
-                $error = KinoSearch::Object::Err->new($@);
-            }
-            KinoSearch::Object::Err->set_error($error);
-            return 0;
-        }
+        $outstream->print($json);
+        $outstream->close;
         return 1;
     }
 
@@ -619,15 +507,13 @@ sub error {$KinoSearch::Object::Err::error}
     sub from_json {
         return to_kino( $json_encoder->decode( $_[1] ) );
     }
-
-    sub set_tolerant { $json_encoder->allow_nonref( $_[1] ) }
 }
 
 {
-    package KinoSearch::Object::Host;
+    package KinoSearch::Util::Host;
     BEGIN {
-        if ( !__PACKAGE__->isa('KinoSearch::Object::Obj') ) {
-            push our @ISA, 'KinoSearch::Object::Obj';
+        if ( !__PACKAGE__->isa('KinoSearch::Obj') ) {
+            push our @ISA, 'KinoSearch::Obj';
         }
     }
 }
@@ -638,11 +524,11 @@ __END__
 
 __BINDING__
 
-my $xs_code = <<'END_XS_CODE';
+my $ks_xs_code = <<'END_XS_CODE';
 MODULE = KinoSearch    PACKAGE = KinoSearch
 
 BOOT:
-    kino_KinoSearch_bootstrap();
+    kino_Boot_bootstrap();
 
 IV
 _dummy_function()
@@ -650,6 +536,10 @@ CODE:
     RETVAL = 1;
 OUTPUT:
     RETVAL
+END_XS_CODE
+
+my $toolset_xs_code = <<'END_XS_CODE';
+MODULE = KinoSearch    PACKAGE = KinoSearch::Util::ToolSet
 
 SV*
 to_kino(sv)
@@ -657,7 +547,7 @@ to_kino(sv)
 CODE:
 {
     kino_Obj *obj = XSBind_perl_to_kino(sv);
-    RETVAL = KINO_OBJ_TO_SV_NOINC(obj);
+    KOBJ_TO_SV_NOINC(obj, RETVAL);
 }
 OUTPUT: RETVAL
 
@@ -666,10 +556,10 @@ to_perl(sv)
     SV *sv;
 CODE:
 {
-    if (sv_isobject(sv) && sv_derived_from(sv, "KinoSearch::Object::Obj")) {
+    if (sv_isobject(sv) && sv_derived_from(sv, "KinoSearch::Obj")) {
         IV tmp = SvIV(SvRV(sv));
         kino_Obj* obj = INT2PTR(kino_Obj*, tmp);
-        RETVAL = XSBind_kino_to_perl(obj);
+        RETVAL = XSBind_kobj_to_pobj(obj);
     }
     else {
         RETVAL = newSVsv(sv);
@@ -678,15 +568,20 @@ CODE:
 OUTPUT: RETVAL
 END_XS_CODE
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel     => "KinoSearch",
     class_name => "KinoSearch",
-    xs_code    => $xs_code,
+    xs_code    => $ks_xs_code,
+);
+Boilerplater::Binding::Perl::Class->register(
+    parcel     => "KinoSearch",
+    class_name => "KinoSearch::Util::Toolset",
+    xs_code    => $toolset_xs_code,
 );
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
