@@ -4,7 +4,7 @@ use KinoSearch;
 
 __END__
 
-__AUTO_XS__
+__BINDING__
 
 my $synopsis = <<'END_SYNOPSIS';
     my $case_folder = KinoSearch::Analysis::CaseFolder->new;
@@ -18,14 +18,15 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $case_folder = KinoSearch::Analysis::CaseFolder->new;
 END_CONSTRUCTOR
 
-{   "KinoSearch::Analysis::CaseFolder" => {
-        make_constructors => ["new"],
-        make_pod          => {
-            synopsis    => $synopsis,
-            constructor => { sample => $constructor },
-        }
+Boilerplater::Binding::Perl::Class->register(
+    parcel            => "KinoSearch",
+    class_name        => "KinoSearch::Analysis::CaseFolder",
+    bind_constructors => ["new"],
+    make_pod          => {
+        synopsis    => $synopsis,
+        constructor => { sample => $constructor },
     },
-}
+);
 
 __COPYRIGHT__
 
