@@ -1,4 +1,3 @@
-package KinoSearch::Highlight::HeatMap;
 use KinoSearch;
 
 1;
@@ -14,7 +13,7 @@ my $constructor = <<'END_CONSTRUCTOR';
     );
 END_CONSTRUCTOR
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel       => "KinoSearch",
     class_name   => "KinoSearch::Highlight::HeatMap",
     bind_methods => [
@@ -22,7 +21,6 @@ Clownfish::Binding::Perl::Class->register(
             Calc_Proximity_Boost
             Generate_Proximity_Boosts
             Flatten_Spans
-            Get_Spans
             )
     ],
     bind_constructors => ["new"],
@@ -34,7 +32,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
