@@ -1,4 +1,3 @@
-package KinoSearch::Index::Snapshot;
 use KinoSearch;
 
 1;
@@ -18,7 +17,7 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $snapshot = KinoSearch::Index::Snapshot->new;
 END_CONSTRUCTOR
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel       => "KinoSearch",
     class_name   => "KinoSearch::Index::Snapshot",
     bind_methods => [
@@ -29,8 +28,7 @@ Clownfish::Binding::Perl::Class->register(
             Delete_Entry
             Read_File
             Write_File
-            Set_Path
-            Get_Path
+            Get_Filename
             )
     ],
     bind_constructors => ["new"],
@@ -45,8 +43,7 @@ Clownfish::Binding::Perl::Class->register(
                 delete_entry
                 read_file
                 write_file
-                set_path
-                get_path
+                get_filename
                 )
         ],
     },
@@ -54,7 +51,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
