@@ -1,4 +1,3 @@
-package KinoSearch::Search::HitQueue;
 use KinoSearch;
 
 1;
@@ -7,7 +6,7 @@ __END__
 
 __BINDING__
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Search::HitQueue",
     bind_constructors => ["new"],
@@ -15,7 +14,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
