@@ -4,7 +4,7 @@ use KinoSearch;
 
 __END__
 
-__AUTO_XS__
+__BINDING__
 
 my $synopsis = <<'END_SYNOPSIS';
     my $not_bar_query = KinoSearch::Search::NOTQuery->new( 
@@ -23,16 +23,17 @@ my $constructor = <<'END_CONSTRUCTOR';
     );
 END_CONSTRUCTOR
 
-{   "KinoSearch::Search::NOTQuery" => {
-        make_constructors => ["new"],
-        bind_methods => [qw( Get_Negated_Query Set_Negated_Query )],
-        make_pod          => {
-            methods => [ qw( get_negated_query set_negated_query ) ],
-            synopsis    => $synopsis,
-            constructor => { sample => $constructor },
-        }
-    },
-}
+Boilerplater::Binding::Perl::Class->register(
+    parcel            => "KinoSearch",
+    class_name        => "KinoSearch::Search::NOTQuery",
+    bind_constructors => ["new"],
+    bind_methods      => [qw( Get_Negated_Query Set_Negated_Query )],
+    make_pod          => {
+        methods     => [qw( get_negated_query set_negated_query )],
+        synopsis    => $synopsis,
+        constructor => { sample => $constructor },
+    }
+);
 
 __COPYRIGHT__
 
