@@ -1,4 +1,3 @@
-package KinoSearch::Search::SortSpec;
 use KinoSearch;
 
 1;
@@ -24,7 +23,7 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $sort_spec = KinoSearch::Search::SortSpec->new( rules => \@rules );
 END_CONSTRUCTOR
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Search::SortSpec",
     bind_methods      => [qw( Get_Rules )],
@@ -37,7 +36,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
