@@ -1,4 +1,3 @@
-package KinoSearch::Util::PriorityQueue;
 use KinoSearch;
 
 1;
@@ -7,7 +6,7 @@ __END__
 
 __BINDING__
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel       => "KinoSearch",
     class_name   => "KinoSearch::Util::PriorityQueue",
     bind_methods => [
@@ -25,7 +24,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
