@@ -1,4 +1,3 @@
-package KinoSearch::Util::StringHelper;
 use KinoSearch;
 
 1;
@@ -37,12 +36,12 @@ PPCODE:
 
 SV*
 to_base36(num)
-    uint64_t num;
+    chy_u32_t num;
 CODE:
 {
-    char base36[kino_StrHelp_MAX_BASE36_BYTES];
-    size_t size = kino_StrHelp_to_base36(num, &base36);
-    RETVAL = newSVpvn(base36, size);
+    kino_CharBuf *buf = kino_StrHelp_to_base36(num);
+    RETVAL = XSBind_cb_to_sv(buf);
+    KINO_DECREF(buf);
 }
 OUTPUT: RETVAL
 
@@ -98,7 +97,7 @@ PPCODE:
 }
 END_XS_CODE
 
-Clownfish::Binding::Perl::Class->register(
+Boilerplater::Binding::Perl::Class->register(
     parcel     => "KinoSearch",
     class_name => "KinoSearch::Util::StringHelper",
     xs_code    => $xs_code,
@@ -106,7 +105,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2009 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
