@@ -1,195 +1,144 @@
 #define C_KINO_OBJ
+#define C_KINO_ZOMBIECHARBUF
 #include "XSBind.h"
+#include "KinoSearch/Store/InStream.h"
+#include "KinoSearch/Store/OutStream.h"
 #include "KinoSearch/Util/StringHelper.h"
 
-// Convert a Perl hash into a KS Hash.  Caller takes responsibility for a
-// refcount.
+/* Convert a Perl hash into a KS Hash.  Caller takes responsibility for a
+ * refcount.
+ */
 static kino_Hash*
-S_perl_hash_to_kino_hash(HV *phash);
+phash_to_khash(HV *phash);
 
-// Convert a Perl array into a KS VArray.  Caller takes responsibility for a
-// refcount.
+/* Convert a Perl array into a KS VArray.  Caller takes responsibility for a
+ * refcount.
+ */
 static kino_VArray*
-S_perl_array_to_kino_array(AV *parray);
-
-// Convert a VArray to a Perl array.  Caller takes responsibility for a
-// refcount.
-static SV*
-S_kino_array_to_perl_array(kino_VArray *varray);
-
-// Convert a Hash to a Perl hash.  Caller takes responsibility for a refcount.
-static SV*
-S_kino_hash_to_perl_hash(kino_Hash *hash);
+parray_to_karray(AV *parray);
 
 kino_Obj*
 XSBind_new_blank_obj(SV *either_sv)
 {
     kino_VTable *vtable;
 
-    // Get a VTable. 
+    /* Get a vtable. */
     if (   sv_isobject(either_sv) 
-        && sv_derived_from(either_sv, "KinoSearch::Object::Obj")
+        && sv_derived_from(either_sv, "KinoSearch::Obj")
     ) {
-        // Use the supplied object's VTable. 
         IV iv_ptr = SvIV(SvRV(either_sv));
         kino_Obj *self = INT2PTR(kino_Obj*, iv_ptr);
         vtable = self->vtable;
     }
     else {
-        // Use the supplied class name string to find a VTable. 
         STRLEN len;
         char *ptr = SvPVutf8(either_sv, len);
-        kino_ZombieCharBuf *klass = KINO_ZCB_WRAP_STR(ptr, len);
-        vtable = kino_VTable_singleton((kino_CharBuf*)klass, NULL);
+        kino_ZombieCharBuf klass = kino_ZCB_make_str(ptr, len);
+        vtable = kino_VTable_singleton((kino_CharBuf*)&klass, NULL);
     }
 
-    // Use the VTable to allocate a new blank object of the right size. 
     return Kino_VTable_Make_Obj(vtable);
 }
 
-kino_Obj*
-XSBind_sv_to_kino_obj(SV *sv, kino_VTable *vtable, void *allocation)
+chy_bool_t
+XSBind_sv_defined(SV *sv)
 {
-    kino_Obj *retval = XSBind_maybe_sv_to_kino_obj(sv, vtable, allocation);
-    if (!retval) {
-        THROW(KINO_ERR, "Not a %o", Kino_VTable_Get_Name(vtable));
-    }
+    if (!sv || !SvANY(sv)) { return false; }
+    if (SvGMAGICAL(sv)) { mg_get(sv); }
+    return SvOK(sv);
+}
+
+kino_Obj*
+XSBind_sv_to_kobj(SV *sv, kino_VTable *vtable) 
+{
+    kino_Obj *retval = XSBind_maybe_sv_to_kobj(sv, vtable);
+    if (!retval) THROW(KINO_ERR, "Not a %o", Kino_VTable_Get_Name(vtable));
     return retval;
 }
 
 kino_Obj*
-XSBind_maybe_sv_to_kino_obj(SV *sv, kino_VTable *vtable, void *allocation)
+XSBind_sv_to_kobj_or_zcb(SV *sv, kino_VTable *vtable, kino_ZombieCharBuf *zcb)
 {
     kino_Obj *retval = NULL;
-    if (XSBind_sv_defined(sv)) {
+    if (!sv || !XSBind_sv_defined(sv)) {
+        THROW(KINO_ERR, "Need a %o, but got NULL or undef", 
+            Kino_VTable_Get_Name(vtable));
+    }
+    else if (   sv_isobject(sv) 
+             && sv_derived_from(sv,
+                 (char*)Kino_CB_Get_Ptr8(Kino_VTable_Get_Name(vtable)))
+    ) {
+        IV tmp = SvIV( SvRV(sv) );
+        retval = INT2PTR(kino_Obj*, tmp);
+    }
+    else if (   vtable == KINO_ZOMBIECHARBUF
+             || vtable == KINO_VIEWCHARBUF
+             || vtable == KINO_CHARBUF
+             || vtable == KINO_OBJ
+    ) {
+        STRLEN size;
+        char *ptr = SvPVutf8(sv, size);
+        Kino_ViewCB_Assign_Str(zcb, ptr, size);
+        retval = (kino_Obj*)zcb;
+    }
+    else THROW(KINO_ERR, "Not a %o", Kino_VTable_Get_Name(vtable));
+    return retval;
+}
+
+kino_Obj*
+XSBind_maybe_sv_to_kobj(SV *sv, kino_VTable *vtable) 
+{
+    kino_Obj *retval = NULL;
+    if (sv && XSBind_sv_defined(sv)) {
         if (   sv_isobject(sv) 
             && sv_derived_from(sv, 
                  (char*)Kino_CB_Get_Ptr8(Kino_VTable_Get_Name(vtable)))
         ) {
-            // Unwrap a real KinoSearch object. 
             IV tmp = SvIV( SvRV(sv) );
             retval = INT2PTR(kino_Obj*, tmp);
         }
-        else if (   allocation &&
-                 (  vtable == KINO_ZOMBIECHARBUF
-                 || vtable == KINO_VIEWCHARBUF
-                 || vtable == KINO_CHARBUF
-                 || vtable == KINO_OBJ)
-        ) {
-            // Wrap the string from an ordinary Perl scalar inside a
-            // ZombieCharBuf.
-            STRLEN size;
-            char *ptr = SvPVutf8(sv, size);
-            retval = (kino_Obj*)kino_ZCB_wrap_str(allocation, ptr, size);
-        }
         else if (SvROK(sv)) {
-            // Attempt to convert Perl hashes and arrays into their KinoSearch
-            // analogues.
             SV *inner = SvRV(sv);
-            if (SvTYPE(inner) == SVt_PVAV && vtable == KINO_VARRAY) {
-                retval = (kino_Obj*)S_perl_array_to_kino_array((AV*)inner);
+            if (SvTYPE(inner) == SVt_PVAV) {
+                if (   vtable == KINO_VARRAY
+                    || vtable == KINO_OBJ
+                ) {
+                    retval = (kino_Obj*)parray_to_karray((AV*)inner);
+                }
             }
-            else if (SvTYPE(inner) == SVt_PVHV && vtable == KINO_HASH) {
-                retval = (kino_Obj*)S_perl_hash_to_kino_hash((HV*)inner);
+            else if (SvTYPE(inner) == SVt_PVHV) {
+                if (   vtable == KINO_HASH
+                    || vtable == KINO_OBJ
+                ) {
+                    retval = (kino_Obj*)phash_to_khash((HV*)inner);
+                }
             }
 
             if(retval) {
-                // Mortalize the converted object -- which is somewhat
-                // dangerous, but is the only way to avoid requiring that the
-                // caller take responsibility for a refcount.
-                SV *mortal = (SV*)Kino_Obj_To_Host(retval);
+                /* Mortalize the KS-ified copy of the Perl data structure. */
+                SV *mortal = Kino_Obj_To_Host(retval);
                 KINO_DECREF(retval);
                 sv_2mortal(mortal);
             }
         }
     }
-
     return retval;
 }
 
-SV*
-XSBind_kino_to_perl(kino_Obj *obj)
+kino_ZombieCharBuf
+XSBind_sv_to_class_name(SV* either_sv) 
 {
-    if (obj == NULL) {
-        return newSV(0);
-    }
-    else if (Kino_Obj_Is_A(obj, KINO_CHARBUF)) {
-        return XSBind_cb_to_sv((kino_CharBuf*)obj);
-    }
-    else if (Kino_Obj_Is_A(obj, KINO_BYTEBUF)) {
-        return XSBind_bb_to_sv((kino_ByteBuf*)obj);
-    }
-    else if (Kino_Obj_Is_A(obj, KINO_VARRAY)) {
-        return S_kino_array_to_perl_array((kino_VArray*)obj);
-    }
-    else if (Kino_Obj_Is_A(obj, KINO_HASH)) {
-        return S_kino_hash_to_perl_hash((kino_Hash*)obj);
-    }
-    else if (Kino_Obj_Is_A(obj, KINO_FLOATNUM)) {
-        return newSVnv(Kino_Obj_To_F64(obj));
-    }
-    else if (sizeof(IV) == 8 && Kino_Obj_Is_A(obj, KINO_INTNUM)) {
-        int64_t num = Kino_Obj_To_I64(obj);
-        return newSViv((IV)num);
-    }
-    else if (sizeof(IV) == 4 && Kino_Obj_Is_A(obj, KINO_INTEGER32)) {
-        int32_t num = (int32_t)Kino_Obj_To_I64(obj);
-        return newSViv((IV)num);
-    }
-    else if (sizeof(IV) == 4 && Kino_Obj_Is_A(obj, KINO_INTEGER64)) {
-        int64_t num = Kino_Obj_To_I64(obj);
-        return newSVnv((double)num); // lossy 
+    if (sv_isobject(either_sv)) {
+        char *name = HvNAME(SvSTASH(SvRV(either_sv)));
+        return kino_ZCB_make_str(name, strlen(name));
     }
     else {
-        return (SV*)Kino_Obj_To_Host(obj);
+        STRLEN size;
+        char *name = SvPVutf8(either_sv, size);
+        return kino_ZCB_make_str(name, size);
     }
 }
 
-kino_Obj*
-XSBind_perl_to_kino(SV *sv)
-{
-    kino_Obj *retval = NULL;
-
-    if (XSBind_sv_defined(sv)) {
-        if (SvROK(sv)) {
-            // Deep conversion of references. 
-            SV *inner = SvRV(sv);
-            if (SvTYPE(inner) == SVt_PVAV) {
-                retval = (kino_Obj*)S_perl_array_to_kino_array((AV*)inner);
-            }
-            else if (SvTYPE(inner) == SVt_PVHV) {
-                retval = (kino_Obj*)S_perl_hash_to_kino_hash((HV*)inner);
-            }
-            else if (   sv_isobject(sv) 
-                     && sv_derived_from(sv, "KinoSearch::Object::Obj")
-            ) {
-                IV tmp = SvIV(inner);
-                retval = INT2PTR(kino_Obj*, tmp);
-                (void)KINO_INCREF(retval);
-            }
-        }
-
-        // It's either a plain scalar or a non-KinoSearch Perl object, so
-        // stringify.
-        if (!retval) {
-            STRLEN len;
-            char *ptr = SvPVutf8(sv, len);
-            retval = (kino_Obj*)kino_CB_new_from_trusted_utf8(ptr, len);
-        }
-    }
-    else if (sv) {
-        // Deep conversion of raw AVs and HVs. 
-        if (SvTYPE(sv) == SVt_PVAV) {
-            retval = (kino_Obj*)S_perl_array_to_kino_array((AV*)sv);
-        }
-        else if (SvTYPE(sv) == SVt_PVHV) {
-            retval = (kino_Obj*)S_perl_hash_to_kino_hash((HV*)sv);
-        }
-    }
-
-    return retval;
-}
-
 SV*
 XSBind_bb_to_sv(const kino_ByteBuf *bb) 
 {
@@ -201,9 +150,7 @@ XSBind_bb_to_sv(const kino_ByteBuf *bb)
 SV*
 XSBind_cb_to_sv(const kino_CharBuf *cb) 
 {
-    if (!cb) { 
-        return newSV(0);
-    }
+    if (!cb) return newSV(0);
     else {
         SV *sv = newSVpvn((char*)Kino_CB_Get_Ptr8(cb), Kino_CB_Get_Size(cb));
         SvUTF8_on(sv);
@@ -212,28 +159,26 @@ XSBind_cb_to_sv(const kino_CharBuf *cb)
 }
 
 static kino_Hash*
-S_perl_hash_to_kino_hash(HV *phash)
+phash_to_khash(HV *phash)
 {
-    uint32_t  num_keys = hv_iterinit(phash);
+    chy_u32_t  num_keys = hv_iterinit(phash);
     kino_Hash *retval   = kino_Hash_new(num_keys);
 
     while (num_keys--) {
         HE *entry = hv_iternext(phash);
         STRLEN key_len;
-        // Copied from Perl 5.10.0 HePV macro, because the HePV macro in
-        // earlier versions of Perl triggers a compiler warning.
+        /* Copied from Perl 5.10.0 HePV macro, because the HePV macro in
+         * earlier versions of Perl triggers a compiler warning. */
         char *key = HeKLEN(entry) == HEf_SVKEY
                   ? SvPV(HeKEY_sv(entry), key_len) 
                   : ((key_len = HeKLEN(entry)), HeKEY(entry));
         SV *value_sv = HeVAL(entry);
         if (!kino_StrHelp_utf8_valid(key, key_len)) {
-            // Force key to UTF-8. This is kind of a buggy area for Perl, and
-            // may result in round-trip weirdness.
+            /* Force key to UTF-8. This is kind of a buggy area for Perl, and
+             * may result in round-trip weirdness. */
             SV *key_sv = HeSVKEY_force(entry);
             key = SvPVutf8(key_sv, key_len);
         }
-
-        // Recurse for each value. 
         Kino_Hash_Store_Str(retval, key, key_len, 
             XSBind_perl_to_kino(value_sv));
     }
@@ -242,13 +187,12 @@ S_perl_hash_to_kino_hash(HV *phash)
 }
 
 static kino_VArray*
-S_perl_array_to_kino_array(AV *parray)
+parray_to_karray(AV *parray)
 {
-    const uint32_t size = av_len(parray) + 1;
+    const chy_u32_t size = av_len(parray) + 1;
     kino_VArray *retval = kino_VA_new(size);
-    uint32_t i;
+    chy_u32_t i;
 
-    // Iterate over array elems. 
     for (i = 0; i < size; i++) {
         SV **elem_sv = av_fetch(parray, i, false);
         if (elem_sv) {
@@ -256,20 +200,61 @@ S_perl_array_to_kino_array(AV *parray)
             if (elem) { Kino_VA_Store(retval, i, elem); }
         }
     }
-    Kino_VA_Resize(retval, size); // needed if last elem is NULL 
+    Kino_VA_Resize(retval, size); /* needed if last elem is NULL */
+
+    return retval;
+}
+
+kino_Obj*
+XSBind_perl_to_kino(SV *sv)
+{
+    kino_Obj *retval = NULL;
+
+    if (sv && XSBind_sv_defined(sv)) {
+        if (SvROK(sv)) {
+            SV *inner = SvRV(sv);
+            if (SvTYPE(inner) == SVt_PVAV) {
+                retval = (kino_Obj*)parray_to_karray((AV*)inner);
+            }
+            else if (SvTYPE(inner) == SVt_PVHV) {
+                retval = (kino_Obj*)phash_to_khash((HV*)inner);
+            }
+            else if (   sv_isobject(sv) 
+                     && sv_derived_from(sv, "KinoSearch::Obj")
+            ) {
+                IV tmp = SvIV(inner);
+                retval = INT2PTR(kino_Obj*, tmp);
+                (void)KINO_INCREF(retval);
+            }
+        }
+
+        /* It's either a plain scalar or a non-KinoSearch Perl object. */
+        if (!retval) {
+            STRLEN len;
+            char *ptr = SvPVutf8(sv, len);
+            retval = (kino_Obj*)kino_CB_new_from_trusted_utf8(ptr, len);
+        }
+    }
+    else if (sv) {
+        if (SvTYPE(sv) == SVt_PVAV) {
+            retval = (kino_Obj*)parray_to_karray((AV*)sv);
+        }
+        else if (SvTYPE(sv) == SVt_PVHV) {
+            retval = (kino_Obj*)phash_to_khash((HV*)sv);
+        }
+    }
 
     return retval;
 }
 
 static SV*
-S_kino_array_to_perl_array(kino_VArray *varray)
+karray_to_parray(kino_VArray *varray)
 {
     AV *perl_array = newAV();
-    uint32_t num_elems = Kino_VA_Get_Size(varray);
+    chy_u32_t num_elems = Kino_VA_Get_Size(varray);
 
-    // Iterate over array elems. 
     if (num_elems) {
-        uint32_t i;
+        chy_u32_t i;
         av_fill(perl_array, num_elems - 1);
         for (i = 0; i < num_elems; i++) {
             kino_Obj *val = Kino_VA_Fetch(varray, i);
@@ -277,8 +262,7 @@ S_kino_array_to_perl_array(kino_VArray *varray)
                 continue;
             }
             else {
-                // Recurse for each value. 
-                SV *const val_sv = XSBind_kino_to_perl(val);
+                SV *const val_sv = XSBind_kobj_to_pobj(val);
                 av_store(perl_array, i, val_sv);
             }
         }
@@ -288,26 +272,24 @@ S_kino_array_to_perl_array(kino_VArray *varray)
 }
 
 static SV*
-S_kino_hash_to_perl_hash(kino_Hash *hash)
+khash_to_phash(kino_Hash *hash)
 {
     HV *perl_hash = newHV();
     SV *key_sv    = newSV(1);
     kino_CharBuf *key;
     kino_Obj     *val;
 
-    // Prepare the SV key. 
+    /* Prepare the SV key. */
     SvPOK_on(key_sv);
     SvUTF8_on(key_sv);
 
-    // Iterate over key-value pairs. 
     Kino_Hash_Iter_Init(hash);
     while (Kino_Hash_Iter_Next(hash, (kino_Obj**)&key, &val)) {
-        // Recurse for each value. 
-        SV *val_sv = XSBind_kino_to_perl(val);
-        if (!Kino_Obj_Is_A((kino_Obj*)key, KINO_CHARBUF)) {
+        SV *val_sv = XSBind_kobj_to_pobj(val);
+        if (!KINO_OBJ_IS_A(key, KINO_CHARBUF)) {
             KINO_THROW(KINO_ERR, 
                 "Can't convert a key of class %o to a Perl hash key",
-                Kino_Obj_Get_Class_Name((kino_Obj*)key));
+                Kino_Obj_Get_Class_Name(key));
         }
         else {
             STRLEN key_size = Kino_CB_Get_Size(key);
@@ -323,6 +305,37 @@ S_kino_hash_to_perl_hash(kino_Hash *hash)
     return newRV_noinc((SV*)perl_hash);
 }
 
+SV*
+XSBind_kobj_to_pobj(kino_Obj *obj)
+{
+    if (obj == NULL) 
+        return newSV(0);
+    else if (KINO_OBJ_IS_A(obj, KINO_CHARBUF))
+        return XSBind_cb_to_sv((kino_CharBuf*)obj);
+    else if (KINO_OBJ_IS_A(obj, KINO_BYTEBUF))
+        return XSBind_bb_to_sv((kino_ByteBuf*)obj);
+    else if (KINO_OBJ_IS_A(obj, KINO_VARRAY))
+        return karray_to_parray((kino_VArray*)obj);
+    else if (KINO_OBJ_IS_A(obj, KINO_HASH))
+        return khash_to_phash((kino_Hash*)obj);
+    else if (KINO_OBJ_IS_A(obj, KINO_FLOATNUM))
+        return newSVnv(Kino_Num_To_F64(obj));
+    else if (sizeof(IV) == 8 && KINO_OBJ_IS_A(obj, KINO_INTNUM)) {
+        chy_i64_t num = Kino_Num_To_I64(obj);
+        return newSViv((IV)num);
+    }
+    else if (sizeof(IV) == 4 && KINO_OBJ_IS_A(obj, KINO_INTEGER32)) {
+        chy_i32_t num = (chy_i32_t)Kino_Num_To_I64(obj);
+        return newSViv((IV)num);
+    }
+    else if (sizeof(IV) == 4 && KINO_OBJ_IS_A(obj, KINO_INTEGER64)) {
+        chy_i64_t num = Kino_Num_To_I64(obj);
+        return newSVnv((double)num); /* lossy */
+    }
+    else 
+        return (SV*)Kino_Obj_To_Host(obj);
+}
+
 void
 XSBind_enable_overload(void *pobj)
 {
@@ -352,70 +365,62 @@ XSBind_enable_overload(void *pobj)
      * and just update every time.
      */
     stash = gv_stashpvn((char*)package_name, size, true);
-    // Gv_AMupdate() changed in Perl 5.11 to take a second argument.
-    // http://www.mail-archive.com/perl5-changes@perl.org/msg23145.html
-#if (PERL_VERSION > 10)
-    Gv_AMupdate(stash, false);
-#else
     Gv_AMupdate(stash);
-#endif
     SvAMAGIC_on(perl_obj);
 }
 
 void
-XSBind_allot_params(SV** stack, int32_t start, int32_t num_stack_elems, 
-                    char* params_hash_name, ...)
+XSBind_allot_params(SV** stack, chy_i32_t start, chy_i32_t num_stack_elems, 
+                    char* defaults_hash_name, ...)
 {
     va_list args;
-    HV *params_hash = get_hv(params_hash_name, 0);
+    HV *defaults_hash = get_hv(defaults_hash_name, 0);
     SV **target;
-    int32_t i;
-    int32_t args_left = (num_stack_elems - start) / 2;
+    chy_i32_t i;
+    chy_i32_t args_left = (num_stack_elems - start) / 2;
 
-    // Retrieve the params hash, which must be a package global. 
-    if (params_hash == NULL) {
-        THROW(KINO_ERR, "Can't find hash named %s", params_hash_name);
-    }
+    /* NOTE: the defaults hash must be declared using "our". */
+    if (defaults_hash == NULL)
+        THROW(KINO_ERR, "Can't find hash named %s", defaults_hash_name);
 
-    // Verify that our args come in pairs. Bail if there are no args. 
-    if (num_stack_elems == start) { return; }
-    if ((num_stack_elems - start) % 2 != 0) {
+    /* Verify that our args come in pairs. Bail if there are no args. */
+    if (num_stack_elems == start) return;
+    if ((num_stack_elems - start) % 2 != 0)
         THROW(KINO_ERR, "Expecting hash-style params, got odd number of args");
-    }
 
-    // Validate param names. 
+    /* Validate param names. */
     for (i = start; i < num_stack_elems; i += 2) {
         SV *const key_sv = stack[i];
         STRLEN key_len;
-        const char *key = SvPV(key_sv, key_len); // assume ASCII labels 
-        if (!hv_exists(params_hash, key, key_len)) {
+        const char *key = SvPV(key_sv, key_len); /* assume ASCII labels */
+        if (!hv_exists(defaults_hash, key, key_len)) {
             THROW(KINO_ERR, "Invalid parameter: '%s'", key);
         }
     }
 
-    va_start(args, params_hash_name); 
+    va_start(args, defaults_hash_name); 
     while (args_left && NULL != (target = va_arg(args, SV**))) {
         char *label = va_arg(args, char*);
         int label_len = va_arg(args, int);
 
-        // Iterate through stack looking for a label match. Work backwards so
-        // that if the label is doubled up we get the last one.
+        /* Iterate through stack looking for a label match. Work backwards so
+         * that if the label is doubled up we get the last one. */
         for (i = num_stack_elems; i >= start + 2; i -= 2) {
-            int32_t tick = i - 2;
+            chy_i32_t tick = i - 2;
             SV *const key_sv = stack[tick];
-            if (SvCUR(key_sv) == (STRLEN)label_len) {
-                if (memcmp(SvPVX(key_sv), label, label_len) == 0) {
-                    *target = stack[tick + 1];
-                    args_left--;
-                    break;
-                }
+            const chy_i32_t comparison = kino_StrHelp_compare_strings(
+                label, SvPVX(key_sv), label_len, SvCUR(key_sv));
+            if (comparison == 0) {
+                *target = stack[tick + 1];
+                args_left--;
+                break;
             }
         }
     }
     va_end(args);
 }
 
-/* Copyright 2005-2010 Marvin Humphrey
+/* Copyright 2005-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
